@@ -16,19 +16,20 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains SFTP hook."""
+
 from __future__ import annotations
 
 import datetime
 import os
 import stat
-import warnings
+from collections.abc import Sequence
 from fnmatch import fnmatch
-from typing import TYPE_CHECKING, Any, Callable, Sequence
+from typing import TYPE_CHECKING, Any, Callable
 
 import asyncssh
 from asgiref.sync import sync_to_async
 
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
 from airflow.providers.ssh.hooks.ssh import SSHHook
 
@@ -39,7 +40,8 @@ if TYPE_CHECKING:
 
 
 class SFTPHook(SSHHook):
-    """Interact with SFTP.
+    """
+    Interact with SFTP.
 
     This hook inherits the SSH hook. Please refer to SSH hook for the input
     arguments.
@@ -59,7 +61,6 @@ class SFTPHook(SSHHook):
     For consistency reasons with SSHHook, the preferred parameter is "ssh_conn_id".
 
     :param ssh_conn_id: The :ref:`sftp connection id<howto/connection:sftp>`
-    :param ssh_hook: Optional SSH hook (included to support passing of an SSH hook to the SFTP operator)
     """
 
     conn_name_attr = "ssh_conn_id"
@@ -79,39 +80,14 @@ class SFTPHook(SSHHook):
     def __init__(
         self,
         ssh_conn_id: str | None = "sftp_default",
-        ssh_hook: SSHHook | None = None,
+        host_proxy_cmd: str | None = None,
         *args,
         **kwargs,
     ) -> None:
         self.conn: paramiko.SFTPClient | None = None
 
-        # TODO: remove support for ssh_hook when it is removed from SFTPOperator
-        self.ssh_hook = ssh_hook
-
-        if self.ssh_hook is not None:
-            warnings.warn(
-                "Parameter `ssh_hook` is deprecated and will be removed in a future version.",
-                AirflowProviderDeprecationWarning,
-                stacklevel=2,
-            )
-            if not isinstance(self.ssh_hook, SSHHook):
-                raise AirflowException(
-                    f"ssh_hook must be an instance of SSHHook, but got {type(self.ssh_hook)}"
-                )
-            self.log.info("ssh_hook is provided. It will be used to generate SFTP connection.")
-            self.ssh_conn_id = self.ssh_hook.ssh_conn_id
-            return
-
-        ftp_conn_id = kwargs.pop("ftp_conn_id", None)
-        if ftp_conn_id:
-            warnings.warn(
-                "Parameter `ftp_conn_id` is deprecated. Please use `ssh_conn_id` instead.",
-                AirflowProviderDeprecationWarning,
-                stacklevel=2,
-            )
-            ssh_conn_id = ftp_conn_id
-
         kwargs["ssh_conn_id"] = ssh_conn_id
+        kwargs["host_proxy_cmd"] = host_proxy_cmd
         self.ssh_conn_id = ssh_conn_id
 
         super().__init__(*args, **kwargs)
@@ -119,11 +95,7 @@ class SFTPHook(SSHHook):
     def get_conn(self) -> paramiko.SFTPClient:  # type: ignore[override]
         """Open an SFTP connection to the remote host."""
         if self.conn is None:
-            # TODO: remove support for ssh_hook when it is removed from SFTPOperator
-            if self.ssh_hook is not None:
-                self.conn = self.ssh_hook.get_conn().open_sftp()
-            else:
-                self.conn = super().get_conn().open_sftp()
+            self.conn = super().get_conn().open_sftp()
         return self.conn
 
     def close_conn(self) -> None:
@@ -133,7 +105,8 @@ class SFTPHook(SSHHook):
             self.conn = None
 
     def describe_directory(self, path: str) -> dict[str, dict[str, str | int | None]]:
-        """Get file information in a directory on the remote system.
+        """
+        Get file information in a directory on the remote system.
 
         The return format is ``{filename: {attributes}}``. The remote system
         support the MLSD command.
@@ -153,7 +126,8 @@ class SFTPHook(SSHHook):
         return files
 
     def list_directory(self, path: str) -> list[str]:
-        """List files in a directory on the remote system.
+        """
+        List files in a directory on the remote system.
 
         :param path: full path to the remote directory to list
         """
@@ -161,8 +135,18 @@ class SFTPHook(SSHHook):
         files = sorted(conn.listdir(path))
         return files
 
+    def list_directory_with_attr(self, path: str) -> list[paramiko.SFTPAttributes]:
+        """
+        List files in a directory on the remote system including their SFTPAttributes.
+
+        :param path: full path to the remote directory to list
+        """
+        conn = self.get_conn()
+        return [file for file in conn.listdir_attr(path)]
+
     def mkdir(self, path: str, mode: int = 0o777) -> None:
-        """Create a directory on the remote system.
+        """
+        Create a directory on the remote system.
 
         The default mode is ``0o777``, but on some systems, the current umask
         value may be first masked out.
@@ -174,7 +158,8 @@ class SFTPHook(SSHHook):
         conn.mkdir(path, mode=mode)
 
     def isdir(self, path: str) -> bool:
-        """Check if the path provided is a directory.
+        """
+        Check if the path provided is a directory.
 
         :param path: full path to the remote directory to check
         """
@@ -186,7 +171,8 @@ class SFTPHook(SSHHook):
         return result
 
     def isfile(self, path: str) -> bool:
-        """Check if the path provided is a file.
+        """
+        Check if the path provided is a file.
 
         :param path: full path to the remote file to check
         """
@@ -198,7 +184,8 @@ class SFTPHook(SSHHook):
         return result
 
     def create_directory(self, path: str, mode: int = 0o777) -> None:
-        """Create a directory on the remote system.
+        """
+        Create a directory on the remote system.
 
         The default mode is ``0o777``, but on some systems, the current umask
         value may be first masked out. Different from :func:`.mkdir`, this
@@ -223,7 +210,8 @@ class SFTPHook(SSHHook):
                 conn.mkdir(path, mode=mode)
 
     def delete_directory(self, path: str) -> None:
-        """Delete a directory on the remote system.
+        """
+        Delete a directory on the remote system.
 
         :param path: full path to the remote directory to delete
         """
@@ -231,7 +219,8 @@ class SFTPHook(SSHHook):
         conn.rmdir(path)
 
     def retrieve_file(self, remote_full_path: str, local_full_path: str, prefetch: bool = True) -> None:
-        """Transfer the remote file to a local location.
+        """
+        Transfer the remote file to a local location.
 
         If local_full_path is a string path, the file will be put
         at that location.
@@ -244,7 +233,8 @@ class SFTPHook(SSHHook):
         conn.get(remote_full_path, local_full_path, prefetch=prefetch)
 
     def store_file(self, remote_full_path: str, local_full_path: str, confirm: bool = True) -> None:
-        """Transfer a local file to the remote location.
+        """
+        Transfer a local file to the remote location.
 
         If local_full_path_or_buffer is a string path, the file will be read
         from that location.
@@ -256,7 +246,8 @@ class SFTPHook(SSHHook):
         conn.put(local_full_path, remote_full_path, confirm=confirm)
 
     def delete_file(self, path: str) -> None:
-        """Remove a file on the server.
+        """
+        Remove a file on the server.
 
         :param path: full path to the remote file
         """
@@ -264,7 +255,8 @@ class SFTPHook(SSHHook):
         conn.remove(path)
 
     def get_mod_time(self, path: str) -> str:
-        """Get an entry's modification time.
+        """
+        Get an entry's modification time.
 
         :param path: full path to the remote file
         """
@@ -273,7 +265,8 @@ class SFTPHook(SSHHook):
         return datetime.datetime.fromtimestamp(ftp_mdtm).strftime("%Y%m%d%H%M%S")  # type: ignore
 
     def path_exists(self, path: str) -> bool:
-        """Whether a remote entity exists.
+        """
+        Whether a remote entity exists.
 
         :param path: full path to the remote file or directory
         """
@@ -286,7 +279,8 @@ class SFTPHook(SSHHook):
 
     @staticmethod
     def _is_path_match(path: str, prefix: str | None = None, delimiter: str | None = None) -> bool:
-        """Whether given path starts with ``prefix`` (if set) and ends with ``delimiter`` (if set).
+        """
+        Whether given path starts with ``prefix`` (if set) and ends with ``delimiter`` (if set).
 
         :param path: path to be checked
         :param prefix: if set path will be checked is starting with prefix
@@ -307,7 +301,8 @@ class SFTPHook(SSHHook):
         ucallback: Callable[[str], Any | None],
         recurse: bool = True,
     ) -> None:
-        """Recursively descend, depth first, the directory tree at ``path``.
+        """
+        Recursively descend, depth first, the directory tree at ``path``.
 
         This calls discrete callback functions for each regular file, directory,
         and unknown file type.
@@ -325,10 +320,9 @@ class SFTPHook(SSHHook):
             (form: ``func(str)``)
         :param bool recurse: *Default: True* - should it recurse
         """
-        conn = self.get_conn()
-        for entry in self.list_directory(path):
-            pathname = os.path.join(path, entry)
-            mode = conn.stat(pathname).st_mode
+        for entry in self.list_directory_with_attr(path):
+            pathname = os.path.join(path, entry.filename)
+            mode = entry.st_mode
             if stat.S_ISDIR(mode):  # type: ignore
                 # It's a directory, call the dcallback function
                 dcallback(pathname)
@@ -345,7 +339,8 @@ class SFTPHook(SSHHook):
     def get_tree_map(
         self, path: str, prefix: str | None = None, delimiter: str | None = None
     ) -> tuple[list[str], list[str], list[str]]:
-        """Get tuple with recursive lists of files, directories and unknown paths.
+        """
+        Get tuple with recursive lists of files, directories and unknown paths.
 
         It is possible to filter results by giving prefix and/or delimiter parameters.
 
@@ -381,7 +376,8 @@ class SFTPHook(SSHHook):
             return False, str(e)
 
     def get_file_by_pattern(self, path, fnmatch_pattern) -> str:
-        """Get the first matching file based on the given fnmatch type pattern.
+        """
+        Get the first matching file based on the given fnmatch type pattern.
 
         :param path: path to be checked
         :param fnmatch_pattern: The pattern that will be matched with `fnmatch`
@@ -394,16 +390,17 @@ class SFTPHook(SSHHook):
         return ""
 
     def get_files_by_pattern(self, path, fnmatch_pattern) -> list[str]:
-        """Get all matching files based on the given fnmatch type pattern.
+        """
+        Get all matching files based on the given fnmatch type pattern.
 
         :param path: path to be checked
         :param fnmatch_pattern: The pattern that will be matched with `fnmatch`
         :return: list of string containing the found files, or an empty list if none matched
         """
         matched_files = []
-        for file in self.list_directory(path):
-            if fnmatch(file, fnmatch_pattern):
-                matched_files.append(file)
+        for file in self.list_directory_with_attr(path):
+            if fnmatch(file.filename, fnmatch_pattern):
+                matched_files.append(file.filename)
 
         return matched_files
 
@@ -515,25 +512,24 @@ class SFTPHookAsync(BaseHook):
         ssh_client_conn = await asyncssh.connect(**conn_config)
         return ssh_client_conn
 
-    async def list_directory(self, path: str = "") -> list[str] | None:
+    async def list_directory(self, path: str = "") -> list[str] | None:  # type: ignore[return]
         """Return a list of files on the SFTP server at the provided path."""
-        ssh_conn = await self._get_conn()
-        sftp_client = await ssh_conn.start_sftp_client()
-        try:
-            files = await sftp_client.listdir(path)
-            return sorted(files)
-        except asyncssh.SFTPNoSuchFile:
-            return None
+        async with await self._get_conn() as ssh_conn:
+            sftp_client = await ssh_conn.start_sftp_client()
+            try:
+                files = await sftp_client.listdir(path)
+                return sorted(files)
+            except asyncssh.SFTPNoSuchFile:
+                return None
 
-    async def read_directory(self, path: str = "") -> Sequence[asyncssh.sftp.SFTPName] | None:
+    async def read_directory(self, path: str = "") -> Sequence[asyncssh.sftp.SFTPName] | None:  # type: ignore[return]
         """Return a list of files along with their attributes on the SFTP server at the provided path."""
-        ssh_conn = await self._get_conn()
-        sftp_client = await ssh_conn.start_sftp_client()
-        try:
-            files = await sftp_client.readdir(path)
-            return files
-        except asyncssh.SFTPNoSuchFile:
-            return None
+        async with await self._get_conn() as ssh_conn:
+            sftp_client = await ssh_conn.start_sftp_client()
+            try:
+                return await sftp_client.readdir(path)
+            except asyncssh.SFTPNoSuchFile:
+                return None
 
     async def get_files_and_attrs_by_pattern(
         self, path: str = "", fnmatch_pattern: str = ""
@@ -549,7 +545,7 @@ class SFTPHookAsync(BaseHook):
         matched_files = [file for file in files_list if fnmatch(str(file.filename), fnmatch_pattern)]
         return matched_files
 
-    async def get_mod_time(self, path: str) -> str:
+    async def get_mod_time(self, path: str) -> str:  # type: ignore[return]
         """
         Make SFTP async connection.
 
@@ -558,9 +554,10 @@ class SFTPHookAsync(BaseHook):
 
         :param path: full path to the remote file
         """
-        ssh_conn = await self._get_conn()
-        sftp_client = await ssh_conn.start_sftp_client()
+        ssh_conn = None
         try:
+            ssh_conn = await self._get_conn()
+            sftp_client = await ssh_conn.start_sftp_client()
             ftp_mdtm = await sftp_client.stat(path)
             modified_time = ftp_mdtm.mtime
             mod_time = datetime.datetime.fromtimestamp(modified_time).strftime("%Y%m%d%H%M%S")  # type: ignore[arg-type]
@@ -568,3 +565,6 @@ class SFTPHookAsync(BaseHook):
             return mod_time
         except asyncssh.SFTPNoSuchFile:
             raise AirflowException("No files matching")
+        finally:
+            if ssh_conn:
+                ssh_conn.close()
